{--------------------------------------------------------}
{                                                        }
{    Grafivox - gerador de grficos para cegos           }
{                                                        }
{    Mdulo de criao interativa de grficos            }
{                                                        }
{    Autor:  Jos Antonio Borges                         }
{                                                        }
{    Em agosto/2018                                      }
{                                                        }
{--------------------------------------------------------}

unit gfintera;

interface
uses dvcrt, dvwin, dvform, dvdigitexto, sysutils,
     gfmsg, gfvars,  gfdesen, gfArq,
     graphics;

procedure passoAPasso;

implementation

{-----------------------------------------------------------}
{                mensagem ao incio da funo               }
{-----------------------------------------------------------}

procedure mensFunc (s: string);
begin
    limpaBaixo(3);
    textBackground (BLUE);
    mensagem (s, 2);
    textBackground (BLACK);

    sintetiza (pegaTextoMensagem('GF_FORM'));   {'Formulrio'}
end;

{-----------------------------------------------------------}
{                   corrige as coordenadas                  }
{-----------------------------------------------------------}

function cc (s: string): string;
begin
    s := trim(s);   // melhorar com mais testes
    if s = '' then
       s := '';
    result := s;
end;

{-----------------------------------------------------------}
{             adiciona comando se tiver parmetros          }
{-----------------------------------------------------------}

procedure adicionaComando (s: string);
begin
    if trim (copy (s, 3, 999)) = '' then
        mensagem ('GFINVAL', 1)    {'Formulrio no foi preenchido'}
    else
        listaComandos.add (s);
end;

{-----------------------------------------------------------}
{                   define o domnio                        }
{-----------------------------------------------------------}

procedure defineDominio;
var xmin, xmax, ymin, ymax: shortString;
begin
    mensFunc ('GF_DOMIN');   {'Domnio'}

    xmin := '';
    xmax := '';
    ymin := '';
    ymax := '';

    formCria;
    formCampo('GF_XMIN', pegaTextoMensagem('GF_XMIN'), xmin, 30); {'X mnimo:'}
    formCampo('GF_XMAX', pegaTextoMensagem('GF_XMAX'), xmax, 30); {'X mximo:'}
    formCampo('GF_YMIN', pegaTextoMensagem('GF_YMIN'), ymin, 30); {'Y mnimo:'}
    formCampo('GF_YMAX', pegaTextoMensagem('GF_YMAX'), ymax, 30); {'Y mximo:'}
    formEdita(True);

    adicionaComando ('DM ' + cc(xmin + ' ' + xmax) + ' ' + cc(ymin + ' ' + ymax));
end;

{-----------------------------------------------------------}
{                   define o contradomnio                  }
{-----------------------------------------------------------}

procedure defineContraDominio;
var xmin, xmax, ymin, ymax: shortString;
begin
    mensFunc ('GF_CTDOM');   {'Contradomnio'}

    mensagem ('GF_0_1', 2);   {'Valores entre 0 e 1'}

    xmin := '';
    xmax := '';
    ymin := '';
    ymax := '';

    formCria;
    formCampo('GF_JXMIN', pegaTextoMensagem('GF_JXMIN'), xmin, 30); {'X mnimo sugiro 0):'}
    formCampo('GF_JXMAX', pegaTextoMensagem('GF_JXMAX'), xmax, 30); {'X mximo (sugiro 1):'}
    formCampo('GF_JYMIN', pegaTextoMensagem('GF_JYMIN'), ymin, 30); {'Y mnimo (entre 0):'}
    formCampo('GF_JYMAX', pegaTextoMensagem('GF_JYMAX'), ymax, 30); {'Y mximo (sugiro 1):'}
    formEdita(True);

    adicionaComando('CD ' + cc(xmin + ' ' + xmax) + ' ' + cc(ymin + ' ' + ymax));
end;

{-----------------------------------------------------------}
{                     define eixos                          }
{-----------------------------------------------------------}

procedure defineEixos;
var ptinic, ptfinal,itick: shortString;
begin
    mensFunc ('GF_EIXO');   {'Eixo'}

    ptinic := '';
    ptfinal := '';
    itick := '';

    formCria;
    formCampo('GF_CINIC',   pegaTextoMensagem ('GF_CINIC'),   ptinic, 30);   {'Coordenada Inicial:'}
    formCampo('GF_CFINAL',  pegaTextoMensagem ('GF_CFINAL'),  ptfinal, 30);  {'Coordenada Final:'}
    formCampo('GF_ITICK',   pegaTextoMensagem ('GF_ITICK'),   itick, 30);    {'Intervalo entre marcas:'}
    formEdita(True);

    adicionaComando('EX ' + cc(ptinic) + ' ' + cc(ptfinal) + ' ' + cc(itick));
end;

{-----------------------------------------------------------}
{                   define a grade                          }
{-----------------------------------------------------------}

procedure defineGrade;
var xmin, xmax, ymin, ymax: shortString;
    itickx, iticky: shortString;
begin
    mensFunc ('GF_GRADE');   {'Grade'}

    xmin := '';
    xmax := '';
    ymin := '';
    ymax := '';
    itickx := '';
    iticky := '';

    formCria;
    formCampo('GF_XMIN', pegaTextoMensagem('GF_XMIN'), xmin, 30); {'X mnimo:'}
    formCampo('GF_YMIN', pegaTextoMensagem('GF_YMIN'), ymin, 30); {'Y mnimo:'}
    formCampo('GF_XMAX', pegaTextoMensagem('GF_XMAX'), xmax, 30); {'Y mximo:'}
    formCampo('GF_YMAX', pegaTextoMensagem('GF_YMAX'), ymax, 30); {'Y mximo:'}
    formCampo('GF_ITICKX', pegaTextoMensagem('GF_ITICKX'), itickx, 30); {'Intervalo X entre marcas:'}
    formCampo('GF_ITICKY', pegaTextoMensagem('GF_ITICKY'), iticky, 30); {'Intervalo Y entre marcas:'}

    formEdita(True);
    if itickx = '' then itickx := '1';
    if iticky = '' then iticky := '1';

    adicionaComando('GR ' + cc(xmin + ' ' + ymin) + ' ' + cc(xmax + ' ' + ymax)
                          + ' ' + cc(itickx + ' ' + iticky));
end;

{-----------------------------------------------------------}
{                   define um ponto                         }
{-----------------------------------------------------------}

procedure definePonto;
var
    x: string;
    c: char;
begin
    mensFunc ('GF_PONTO');      { 'Ponto' }

    mensagem ('GF_COORD', 0);    {'Coordenadas'}

    x := '';
    c := sintEdita(x, wherex, wherey, 30, true);
    if c = ESC then
        begin
            mensagem ('GFDESIST', 2);
            exit;
        end;

    adicionaComando('PT ' + cc(x));
end;

{--------------------------------------------------------}
{           definies comuns para reta ou seta          }
{--------------------------------------------------------}

procedure defineRetaOuSeta (comSeta: boolean);
var
    si, sf: ShortString;
begin
    if comSeta then
        mensFunc ('GF_SETA')         { 'Seta' }
    else
        mensFunc ('GF_RETA');        { 'Reta' }

    si := '';
    sf := '';
    formCria;
    formCampo('GF_PTI', pegaTextoMensagem('GF_PTI'), si, 30); {'Ponto inicial:'}
    formCampo('GF_PTI', pegaTextoMensagem('GF_PTF'), sf, 30); {'Ponto final:'}
    formEdita(True);

    if comSeta then
        adicionaComando('ST ' + cc(si) + ' ' + cc(sf))
    else
        adicionaComando('RT ' + cc(si) + ' ' + cc(sf));
end;

{--------------------------------------------------------}
{                   define uma reta                      }
{--------------------------------------------------------}

procedure defineReta;
begin
    defineRetaOuSeta (false);
end;

{--------------------------------------------------------}
{                   define uma seta                      }
{--------------------------------------------------------}

procedure defineSeta;
begin
    defineRetaOuSeta (true);
end;

{--------------------------------------------------------}
{                     define um retngulo                }
{--------------------------------------------------------}

procedure defineRetangulo;
var
    si, sf: ShortString;
begin
    mensFunc ('GF_RETANG');        { 'Reta' }

    si := '';
    sf := '';
    formCria;
    formCampo('GF_INFE', pegaTextoMensagem('GF_INDF'), si, 30); {'Ponto inferior esquerdo:'}
    formCampo('GF_DIME', pegaTextoMensagem('GF_DIME'), sf, 30); {'Dimensoes:'}
    formEdita(True);

    adicionaComando('RG ' + cc(si) + ' ' + cc(sf));
end;

{--------------------------------------------------------}
{                     define um retngulo                }
{--------------------------------------------------------}

procedure defineRetangRodado;
var
    si, sf, ang: ShortString;
begin
    mensFunc ('GF_RETANG');        { 'Retngulo' }

    si := '';
    sf := '';
    ang := '';

    formCria;
    formCampo('GF_INFE', pegaTextoMensagem('GF_INDF'), si, 30); {'Ponto inferior esquerdo:'}
    formCampo('GF_DIME', pegaTextoMensagem('GF_DIME'), sf, 30); {'dx dy:'}
    formCampo('GF_ANG', pegaTextoMensagem('GF_ANG'), ang, 30);  {'ngulo em graus:'}
    formEdita(True);

    adicionaComando('RR ' + cc(si) + ' ' + cc(sf) + ' ' + ang);
end;

{--------------------------------------------------------}
{                     define um polgono                 }
{--------------------------------------------------------}

procedure definePoligono;
var
    pt1, pt2, pt3, pt4, pt5: shortString;
begin
    mensFunc ('GF_POLIG');        { 'Polgono' }

    mensagem ('GF_QLDADOS', 0);  {'Quer utilizar dados lidos de arquivo? '}
    if popupMenuPorLetra('SN') = 'S' then
        begin
            adicionaComando('PO *');
            exit;
        end;

    mensagem ('GF_DEIXBR', 0);  {'Deixe em branco os pontos inexistentes'}
    formCria;
    formCampo('GF_PT1', pegaTextoMensagem('GF_PT1'), pt1, 30); {'Ponto 1:'}
    formCampo('GF_PT2', pegaTextoMensagem('GF_PT2'), pt2, 30); {'Ponto 2:'}
    formCampo('GF_PT3', pegaTextoMensagem('GF_PT3'), pt3, 30); {'Ponto 3:'}
    formCampo('GF_PT4', pegaTextoMensagem('GF_PT4'), pt4, 30); {'Ponto 4:'}
    formCampo('GF_PT5', pegaTextoMensagem('GF_PT5'), pt5, 30); {'Ponto 5:'}
    formEdita(True);

    adicionaComando(trim('PO ' + pt1 + ' ' + pt2 + ' ' +
                                   pt3 + ' ' + pt4 + ' ' + pt5));
end;

{--------------------------------------------------------}
{                define uma circunferncia               }
{--------------------------------------------------------}

procedure defineCircunf;
var centro, raio: shortString;
begin
    mensFunc ('GF_CIRC');    {'Circunferncia'}

    centro := '';
    raio := '';
    formCria;
    formCampo('GF_CENTRO', pegaTextoMensagem('GF_CENTRO'), centro, 30); {'Centro:'}
    formCampo('GF_RAIO',   pegaTextoMensagem('GF_RAIO'), raio, 30);     {'Raio:'}
    formEdita(True);

    adicionaComando('CI ' + cc(centro) + ' ' + raio);
end;

{--------------------------------------------------------}
{                     define uma elipse                  }
{--------------------------------------------------------}

procedure defineElipse;
var centro, a, b: shortString;
begin
    mensFunc ('GF_ELIPSE');  {'Elipse'}

    centro := '';
    a := '';
    b := '';
    formCria;
    formCampo('GF_CENTRO', pegaTextoMensagem('GF_CENTRO'), centro, 30); {'Centro:'}
    formCampo('GF_AELIPS', pegaTextoMensagem('GF_AELIPS'), A, 30);  {'A (meia dim. horizontal):'}
    formCampo('GF_AELIPS', pegaTextoMensagem('GF_BELIPS'), B, 30);  {'B (meia dim. vertical):'}
    formEdita(True);

    adicionaComando('EL ' + cc(centro) + ' ' + cc(a + ' ' + b));
end;

{--------------------------------------------------------}
{                    define uma parbola                 }
{--------------------------------------------------------}

procedure defineParabola;
var pt1, pt2, pt3: shortString;
begin
    mensFunc ('GF_PARAB');   {'Parbola'}

    pt1 := '';
    pt2 := '';
    pt3 := '';
    formCria;
    formCampo('GF_PT1', pegaTextoMensagem('GF_PT1'), pt1, 30); {'Ponto 1:'}
    formCampo('GF_PT2', pegaTextoMensagem('GF_PT2'), pt2, 30); {'Ponto 2:'}
    formCampo('GF_PT3', pegaTextoMensagem('GF_PT3'), pt3, 30); {'Ponto 3:'}
    formEdita(True);

    adicionaComando('PA ' + cc(pt1) + ' ' + cc(pt2) + ' ' +cc(pt3));
end;

{--------------------------------------------------------}
{                     define uma curva                   }
{--------------------------------------------------------}

procedure defineCurva;
var npt: shortString;
    pt1, pt2, pt3, pt4, pt5: shortString;
begin
    mensFunc ('GF_CURVA');   {'Curva'}

    mensagem ('GF_QLDADOS', 0);  {'Quer utilizar dados lidos de arquivo? '}
    if popupMenuPorLetra('SN') = 'S' then
        begin
            adicionaComando('CV *');
            exit;
        end;

    writeln;
    mensagem ('GF_DEIXBV', 2);  {'Deixe em branco os valores inexistentes'}

    formCria;
    formCampo('GF_PT1', pegaTextoMensagem('GF_PT1'), pt1, 30); {'Ponto 1:'}
    formCampo('GF_PT2', pegaTextoMensagem('GF_PT2'), pt2, 30); {'Ponto 2:'}
    formCampo('GF_PT3', pegaTextoMensagem('GF_PT3'), pt3, 30); {'Ponto 3:'}
    formCampo('GF_PT4', pegaTextoMensagem('GF_PT4'), pt4, 30); {'Ponto 4:'}
    formCampo('GF_PT5', pegaTextoMensagem('GF_PT5'), pt5, 30); {'Ponto 5:'}
    formEdita(True);

    adicionaComando(trim('CV ' + pt1 + ' ' + pt2 + ' ' +
                                 pt3 + ' ' + pt4 + ' ' + pt5));
end;

{--------------------------------------------------------}
{                   define um polinmio                  }
{--------------------------------------------------------}

procedure definePolinomio;
var grau: shortString;
    ind0, ind1, ind2, ind3, ind4: shortString;
    xmin, xmax: shortString;
    cmd: string;
begin
    mensFunc ('GF_POLIN');   {'Polinmio'}
    mensagem ('GF_DEIXBV', 2);  {'Deixe em branco os valores inexistentes'}

    formCria;
    formCampo('GF_GRAU', pegaTextoMensagem('GF_GRAU'), grau, 30); {'Grau:'}
    formCampo('GF_CX4',  pegaTextoMensagem('GF_CX4'),  ind4, 30); {'Coef. x^4: '}
    formCampo('GF_CX3',  pegaTextoMensagem('GF_CX3'),  ind3, 30); {'Coef. x^3: '}
    formCampo('GF_CX2',  pegaTextoMensagem('GF_CX2'),  ind2, 30); {'Coef. x^2: '}
    formCampo('GF_CX1',  pegaTextoMensagem('GF_CX1'),  ind1, 30); {'Coef. x^1: '}
    formCampo('GF_CX0',  pegaTextoMensagem('GF_CX0'),  ind0, 30); {'Termo indep.: :'}
    formCampo('GF_XMIN', pegaTextoMensagem('GF_XMAX'), xmin, 30); {'X min'}
    formCampo('GF_XMAX', pegaTextoMensagem('GF_XMIN'), xmax, 30); {'X max:'}
    formEdita(True);

    cmd := trim('PN ' + grau + ' ' + ind4 + ' ' + ind3 + ' ' +
                        ind2 + ' ' + ind1 + ' ' + ind0 + ' ' +
                        xmin + ' ' + xmax);
    cmd := StringReplace(cmd, '  ', ' ', [rfReplaceAll]);
    adicionaComando(cmd);
end;

{--------------------------------------------------------}
{                   define uma equacao                   }
{--------------------------------------------------------}


procedure defineEquacao;
begin
    mensFunc ('GF_EQUACAO'); {'Equao'}

    naoImplem;
//    adicionaComando('EQ ' + '');
end;

{--------------------------------------------------------}
{                 define um texto em Braille             }
{--------------------------------------------------------}

procedure defineTextoBraille;
var coord, txt: shortString;
begin
    mensFunc ('GF_TXTB');   {'Texto em Braille'}

    coord := '';
    txt := '';
    formCria;
    formCampo('GF_COORD', pegaTextoMensagem('GF_COORD'), coord, 30); {'Coordenadas:'}
    formCampo('GF_TEXTO', pegaTextoMensagem('GF_TEXTO'), txt, 80);   {'Texto:'}
    formEdita(True);

    adicionaComando('TB ' + cc(coord) + ' ' + txt);
end;

{--------------------------------------------------------}
{              define um texto em tinta                  }
{--------------------------------------------------------}

procedure defineTextoTinta;
var coord, txt: shortString;
begin
    mensFunc ('GF_TXTT');   {'Texto em Tinta'}

    coord := '';
    txt := '';
    formCria;
    formCampo('GF_COORD', pegaTextoMensagem('GF_COORD'), coord, 30); {'Coordenadas:'}
    formCampo('GF_TEXTO', pegaTextoMensagem('GF_TEXTO'), txt, 80);   {'Texto:'}
    formEdita(True);

    adicionaComando('TX ' + cc(coord) + ' ' + txt);
end;

procedure defineHistograma;
var coord, largura, nBarras: shortString;
    br1, br2, br3, br4, br5, br6, br7, br8, br9, br10, br11, br12: shortString;

begin
    mensFunc ('GF_HISTO');   {'Histograma'}

    mensagem ('GF_DEIXBV', 2);   {'Deixe em branco os valores inexistentes'}

    formCria;
    formCampo('GF_COORD', pegaTextoMensagem('GF_COORD'), coord, 30);    {'Coordenadas:'}
    formCampo('GF_LARGB', pegaTextoMensagem('GF_LARGB'), largura, 30);  {'Largura das barras:'}
    formCampo('GF_BR1',   pegaTextoMensagem('GF_PBR1'), br1, 30);       {'Barra 1:'}
    formCampo('GF_BR1',   pegaTextoMensagem('GF_PBR2'), br2, 30);       {'Barra 2:'}
    formCampo('GF_BR3',   pegaTextoMensagem('GF_PBR3'), br3, 30);       {'Barra 3:'}
    formCampo('GF_BR4',   pegaTextoMensagem('GF_PBR4'), br4, 30);       {'Barra 4:'}
    formCampo('GF_BR5',   pegaTextoMensagem('GF_PBR5'), br5, 30);       {'Barra 5:'}
    formCampo('GF_BR6',   pegaTextoMensagem('GF_PBR6'), br6, 30);       {'Barra 6:'}
    formCampo('GF_BR7',   pegaTextoMensagem('GF_PBR7'), br7, 30);       {'Barra 7:'}
    formCampo('GF_BR8',   pegaTextoMensagem('GF_PBR8'), br8, 30);       {'Barra 8:'}
    formCampo('GF_BR9',   pegaTextoMensagem('GF_PBR9'), br9, 30);       {'Barra 9:'}
    formCampo('GF_BR10',  pegaTextoMensagem('GF_PBR10'), br10, 30);     {'Barra 10:'}
    formCampo('GF_BR11',  pegaTextoMensagem('GF_PBR11'), br11, 30);     {'Barra 11:'}
    formCampo('GF_BR12',  pegaTextoMensagem('GF_PBR12'), br12, 30);     {'Barra 12:'}
    formEdita(True);

    adicionaComando(trim('HI ' + cc(coord) + ' ' + largura + ' ' +
          br1 + ' ' + br2 + ' ' + br3 + ' ' + br4 + ' ' + br5 + ' ' + br6 + ' ' +
          br7 + ' ' + br8 + ' ' + br9 + ' ' + br10 + ' ' + br11 + ' ' + br12));
end;

{--------------------------------------------------------}
{             define a configurao da caneta            }
{--------------------------------------------------------}

procedure defineConfigCaneta;
var
    largura, estilo, cor: shortstring;
begin
    mensFunc ('GF_CANETA');   {'Configurao da caneta'}

    largura := '';
    cor := '';
    estilo := '';
    formCria;
    formCampo('GF_LARG', pegaTextoMensagem('GF_LARG'), largura, 10);  {'Largura (1..5)'}
    formCampoLista('GF_ESTILO', pegaTextoMensagem('GF_estilo'), estilo, 15,
                              '0-NORMAL|1-PONTILHADA|2-TRACEJADA');  {'Largura'}
    formCampoLista ('GF_COR', pegaTextoMensagem('GF_COR'), cor, 15,
                              '0-PRETA|1-VERMELHA|2-AZUL');  {'Cor'}
    formEdita(true);

    if largura = '' then largura := '1';
    adicionaComando('CC ' + copy (largura, 1, 1) + ' ' +
                            copy (estilo, 1, 1) + ' ' +
                            copy (cor, 1, 1));
end;

{--------------------------------------------------------}
{             define a configurao da caneta            }
{--------------------------------------------------------}

procedure defineLeDados;
var
    nomeArq: string;
begin
    mensFunc ('GF_LEDADOS');   {'Leitura de dados'}
    sintWriteln ('Nome do arquivo: ');
    sintReadln (nomeArq);
    adicionaComando('LD ' + nomeArq);
end;

{--------------------------------------------------------}
{        define a configurao do texto em tinta         }
{--------------------------------------------------------}

procedure defineConfigTextoTinta;
begin
    mensFunc ('GF_CNFTINTA');   {'Configurao do texto em tinta'}

    naoImplem;
    adicionaComando('CT' + '');
end;

{--------------------------------------------------------}
{            seleciona a opo com as setas
{--------------------------------------------------------}

type TCOMANDO = string[2];

function selSetasComando: TCOMANDO;

    procedure MenuAdiciona (msg: string);
    begin
         popupMenuAdiciona (msg, pegaTextoMensagem (msg));
    end;

var
    n: integer;
    salvaY: integer;

const
    tabLetrasComando: array [1..22] of TCOMANDO =
       (
        'PT','RT','ST','RG','RR','GR','EX','PO','CI',
        'EL','PA','CV','PN','EQ','HI','LD','DM','CD',
        'CC','TX','TT','CT'
       );
begin
    salvaY := whereY;

    garanteEspacoTela (16);
    popupMenuCria (wherex, wherey, 50, 15, MAGENTA);

    menuAdiciona ('GFCOM_PT');  {'PT - Ponto'}
    menuAdiciona ('GFCOM_RT');  {'RT - Reta'}
    menuAdiciona ('GFCOM_ST');  {'ST - Seta'}
    menuAdiciona ('GFCOM_RG');  {'RG - Retngulo'}
    menuAdiciona ('GFCOM_RR');  {'RR - Retngulo rodado'}

    menuAdiciona ('GFCOM_GR');  {'GR - Grade'}
    menuAdiciona ('GFCOM_EX');  {'EX - Eixos'}

    menuAdiciona ('GFCOM_PO');  {'PO - Poligono'}
    menuAdiciona ('GFCOM_CI');  {'CI - Circunferncia'}
    menuAdiciona ('GFCOM_EL');  {'EL - Elipse'}
    menuAdiciona ('GFCOM_PA');  {'PA - Parbola'}
    menuAdiciona ('GFCOM_CV');  {'CV - Curva'}
    menuAdiciona ('GFCOM_PN');  {'PN - Polinmio'}
    menuAdiciona ('GFCOM_EQ');  {'EQ - Equao'}
    menuAdiciona ('GFCOM_HI');  {'HI - Histograma'}
    menuAdiciona ('GFCOM_LD');  {'LD - Le dados de arquivo'}

    menuAdiciona ('GFCOM_DM');  {'DM - Definir domnio'}
    menuAdiciona ('GFCOM_CM');  {'CD - Definir contradomnio'}

    menuAdiciona ('GFCOM_CC');  {'CC - Configurar Caneta'}
    menuAdiciona ('GFCOM_TB');  {'TX - Texto em Braille'}
    menuAdiciona ('GFCOM_TT');  {'TT - Texto em Tinta'}
    menuAdiciona ('GFCOM_CT');  {'CT - Configurar Texto em Tinta'}

    menuAdiciona ('GF_ESC');    {'ESC - terminar'}

    n := popupMenuSeleciona;
    if n > 0 then
        begin
            selSetasComando := tabLetrasComando[n];
            writeln (tabLetrasComando[n]);
        end
    else
        selSetasComando := ESC;
    limpaBaixo (salvaY);
end;

{--------------------------------------------------------}
{                   criao interativa                   }
{--------------------------------------------------------}

procedure passoAPasso;
var
    c, c2, lixo: char;
    scom: TCOMANDO;
    comando: string;
label
    fim;

begin
    while true do
        begin
            clrscr;
            textBackground (BLUE);
            writeln (pegaTextoMensagem ('GF_PINTER'));  {'Passo-a-passo interativo'}
            textBackground (BLACK);
            writeln;

            mensagem ('GFDIGCOM', 0);      { 'Digite o comando '}
            textBackground (BLACK);
            sintLeTecla (c, c2);
            if c = ENTER then
                begin
                    visualiza(false);
                    continue;
                end;

            if upcase(c) in ['A'..'Z'] then
                begin
                    sintLeTecla (c2, lixo);
                    scom := upperCase(c+c2);
                end;

            comando := '';
            if (c = #0) and ((c2 = CIMA) or (c2 = BAIX) or (c2 = F9)) then
                  begin
                      scom := selSetasComando;
                      if c <> #$1b then
                          comando := copy (
                             opcoesItemSelecionado, pos ('-', opcoesItemSelecionado)-1, 999);
                  end;

            if c = #$1b then
                begin
                    writeln;
                    goto fim;
                end;

            if c2 = ENTER then
                begin
                    writeln;
                    case upcase(c) of
                        'S': salvaArquivo;
                        'V': visualiza(false);
                    else
                        mensagem ('GFOPINV', 1); {'Opo invlida'}
                    end
                end

            else
            if (c = #0) and (c2 = F1) then
                 { ajudaComando }
            else
                begin
                    limpaBaixo(3);
                    textBackground (BLUE);
                    writeln ('Comando' + comando);
                    textBackground (BLACK);
                    writeln;
                    scom := upperCase(scom);

                    if      sCom = 'PT' then definePonto
                    else if sCom = 'RT' then defineReta
                    else if sCom = 'ST' then defineSeta
                    else if sCom = 'RG' then defineRetangulo
                    else if sCom = 'RR' then defineRetangRodado

                    else if sCom = 'GR' then defineGrade
                    else if sCom = 'EX' then defineEixos

                    else if sCom = 'PO' then definePoligono
                    else if sCom = 'CI' then defineCircunf
                    else if sCom = 'EL' then defineElipse
                    else if sCom = 'PA' then defineParabola
                    else if sCom = 'CV' then defineCurva
                    else if sCom = 'PN' then definePolinomio
                    else if sCom = 'EQ' then defineEquacao
                    else if sCom = 'HI' then defineHistograma
                    else if sCom = 'LD' then defineLeDados

                    else if sCom = 'DM' then defineDominio
                    else if sCom = 'CD' then defineContraDominio

                    else if sCom = 'CC' then defineConfigCaneta
                    else if sCom = 'TB' then defineTextoBraille
                    else if sCom = 'TX' then defineTextoTinta
                    else if sCom = 'CT' then defineConfigTextoTinta

                    else
                    if scom = ESC  then
                       {}
                    else
                        begin
                            mensagem ('GFOPINV', 1); {'Opo invlida'}
                            delay (500);
                        end;
                end;
        end;
fim:
    writeln;
end;

end.

